Fragalysis
==========

Basic RDKit based Python tools for analysis of protein-ligand interactions.

Currently contains the following: -

1.  Clustering - based on WONKA method - but separated from that code-base.
    Cluster waters, residues, ligands and pharmacophores. (Under development)
2.  Astex Fragment Network - implementation on the basis of their recent paper
3.  Conformer generation code - based on known X-ray structures
